︠0ac43777-2003-420a-b4fb-a775d62145c3︠
"""This sheet is used to compute the matrix B from the paper Stable symmetric polynomials and the Schur-Agler class.  It would help to refer to equation (3.4) from the arxiv version of that paper."""
︡1fa3d6e2-0b1a-4c5a-9985-4250ea8b2742︡{"stdout": "'This sheet is used to compute the matrix B from the paper Stable symmetric polynomials and the Schur-Agler class.  It would help to refer to equation (3.4) from the arxiv version of that paper.'"}︡
︠12d29ede-0698-4090-b20b-f6ca070f57d5︠
"""The matrix B has its rows and columns indexed by subsets of {0,1,2,...,d-2}.  I found it convenient to represent the subsets using binary expansions.  The following function just gives the number of 1's in the binary expansion of a natural number (which would correspond to the size of a subset)."""
︡fd3501a1-ccd0-4f24-ab67-c4321e8d893c︡{"stdout": "\"The matrix B has its rows and columns indexed by subsets of {0,1,2,...,d-2}.  I found it convenient to represent the subsets using binary expansions.  The following function just gives the number of 1's in the binary expansion of a natural number (which would correspond to the size of a subset).\""}︡
︠aef14cb5-b907-42ae-b5a2-62c99ee6501b︠
"""For example, the subset {0,2,3} of {0,1,..,4} would correspond to the bitstring 01101 = 1+2^2+2^4=21, and bitsize(21) would give 3."""
︡c0062db6-c128-46a3-933e-54d84925ac6d︡{"stdout": "'For example, the subset {0,2,3} of {0,1,..,4} would correspond to the bitstring 01101 = 1+2^2+2^4=21, and bitsize(21) would give 3.'"}︡
︠d64c7d47-2cbc-4bd2-8b59-cd2b067e3dc8︠
def bitsize(n):
    m = 0
    while n != 0:
        m = (n % 2) + m
        n = n >> 1
    return m
︡04b14e18-6df9-4081-a15e-bd02c81c63da︡︡
︠2e3aabe9-6584-4a0c-98ee-d17eb1101a0d︠
bitsize(21)
︡53423d61-4ed4-48d0-886d-2bfe780d3a8d︡{"stdout": "3"}︡
︠bfae8da6-c165-4ad9-907d-7bf2470e321e︠
"""This next function returns the location of the 1 furthest to the right in a binary expansion.  Again, 21 = 01101 and so findbit(21) should return 0. While findbit(16) should return 4 since 16=10000 in binary and 1 is in the 2^4 place."""
︡92079d9a-9c16-4e8e-a7c0-7608f41fd0d7︡{"stdout": "'This next function returns the location of the 1 furthest to the right in a binary expansion.  Again, 21 = 01101 and so findbit(21) should return 0. While findbit(16) should return 4 since 16=10000 in binary and 1 is in the 2^4 place.'"}︡
︠c33973a6-8fb9-4f46-a3e3-55b0fa45a973︠
def findbit(n):
    m = 0
    while n != 0:
        if n % 2 == 1:
            n = 0
        else:
            n = n >> 1
        m = m+1
    return m-1
︡001138dc-fa87-4fc3-b371-e875dc152fa8︡︡
︠0b04df36-5e4b-4570-b6e7-e450eae226bb︠
findbit(21), findbit(16)
︡84316dee-5bdb-46d3-a9e5-692fce482d9a︡{"stdout": "(0, 4)"}︡
︠bd8c8b76-5223-4629-b5b6-592763ae33a5︠
"""This next function gives the matrix B from the paper Stable symmetric polynomials and the Schur-Agler class.  See equation (3.4) from the arxiv version (which may differ in older versions).  The input is a vector of coefficients of a polynomial and the output is the corresponding matrix B."""
︡7f1a4deb-e96a-40c6-8a4a-6228a4739c98︡{"stdout": "'This next function gives the matrix B from the paper Stable symmetric polynomials and the Schur-Agler class.  See equation (3.4) from the arxiv version (which may differ in older versions).  The input is a vector of coefficients of a polynomial and the output is the corresponding matrix B.'"}︡
︠97fe4d2a-6f9c-4b6f-9730-735e21bc9454︠
def Bmatrix(coefs):
    B = []                          #initialize the array 
    if len(coefs) != 0:             #Make sure there is at least 1 coefficient
        L = len(coefs)              #The number of coefficients of the polynomial
        N = 2^(L-2)                 #This will be the number of rows and columns of the matrix
        for i in range(N):          #Begin to construct the array
            B.append([])            #Put an empty row into the array
            i_len = bitsize(i)      #The number i corresponds to a subset with i_len elements  
            for j in range(N):      #Start looping over the columns  
                j_len = bitsize(j)  #The number j corresponds to a subset with j_len elements
                # 
                # The next expression computes part of the left hand side of equation (3.4) from 
                # the paper.
                #
                schurcohn = coefs[i_len]*coefs[j_len] - coefs[L-1- j_len]* coefs[L - 1 - i_len]
                # 
                # The next expression computes the full expression on the left hand side of equation (3.4) divided by
                # (d-j-k-1) which occurs on the right side.
                #
                C = (1/(L-1 - i_len - j_len + bitsize(i & j)))*(1/(binomial(L-1, i_len)*binomial(L-1,j_len)))*(schurcohn)
                if i & j == 0:   #If the subsets corresponding to i and j do not intersect the recursion in equation 
                                 # (3.4) stops.   
                    B[i].append(C)
                else:            #Otherwise, we need to compute B^{i-1}_{j-1,k-1} which we have already done. 
                    back_i = i - 2^(findbit(i&j))
                    back_j = j - 2^(findbit(i&j))
                    D = B[back_i][back_j]
                    B[i].append(C + bitsize(i & j) * D/(L-1 - i_len - j_len + bitsize(i & j)))
    return B
︡f635b1d7-cf57-4de2-9bcd-9cac3b8beebe︡︡
︠6b4e4f9f-a2f5-43da-9f47-7fbf25700ebf︠
"""For example if my polynomial is p(z) = 1-z=1+(-1)z+0z^2+0z^3+0z^4 which I want to view as a polynomial of degree at most 4 (the degree is important for symmetrization) I could set:"""
︡8313317d-d212-4825-9e90-4adb5a9b2af9︡{"stdout": "'For example if my polynomial is p(z) = 1-z=1+(-1)z+0z^2+0z^3+0z^4 which I want to view as a polynomial of degree at most 4 (the degree is important for symmetrization) I could set:'"}︡
︠a6a458cc-c2be-4db6-9d44-c868818fffe0︠
p = [1,-1,0,0,0]
︡fcb89252-d337-4370-9e7b-be9de8045a2e︡︡
︠a85c0f45-06df-4482-88d5-137f842afe61︠
"""Then, the following command would give me an array of the matrix B, which I need to convert into a matrix"""
︡a01d3deb-f11e-46bb-a6b5-26c6f830b661︡{"stdout": "'Then, the following command would give me an array of the matrix B, which I need to convert into a matrix'"}︡
︠5b39d410-0ee0-4074-b9f8-16f2e6bf0ccb︠
X = matrix(Bmatrix(p))
︡f769fc10-ba18-4095-a0a7-511ffc99740a︡︡
︠cd839947-c575-4451-bbcd-13df77a5f30e︠
X
︡d7065843-0958-4484-9c2a-97db706a676e︡{"stdout": "matrix([[ 0.25      , -0.08333333, -0.08333333,  0.        , -0.08333333,\n          0.        ,  0.        ,  0.        ],\n        [-0.08333333,  0.10416667,  0.03125   , -0.04166667,  0.03125   ,\n         -0.04166667,  0.        ,  0.        ],\n        [-0.08333333,  0.03125   ,  0.10416667, -0.04166667,  0.03125   ,\n          0.        , -0.04166667,  0.        ],\n        [ 0.        , -0.04166667, -0.04166667,  0.10416667,  0.        ,\n          0.03125   ,  0.03125   , -0.08333333],\n        [-0.08333333,  0.03125   ,  0.03125   ,  0.        ,  0.10416667,\n         -0.04166667, -0.04166667,  0.        ],\n        [ 0.        , -0.04166667,  0.        ,  0.03125   , -0.04166667,\n          0.10416667,  0.03125   , -0.08333333],\n        [ 0.        ,  0.        , -0.04166667,  0.03125   , -0.04166667,\n          0.03125   ,  0.10416667, -0.08333333],\n        [ 0.        ,  0.        ,  0.        , -0.08333333,  0.        ,\n         -0.08333333, -0.08333333,  0.25      ]])"}︡
︠b9311e5f-c58b-45df-9d3e-7f9f322b1d84︠
"""Unfortunately the ordering of the index set for the rows and columns differs from the paper (and this makes it difficult to see all of the symmetry.  Rows and columns are indexed by subsets of {0,1,2}.  The ordering is given by converting numbers into binary expansions and then viewing binary expansions as subsets.  So, 0,1,2,3,4,5,6,7 have binary expansions 000, 001, 010, 011, 100, 101, 110, 111 and these correspond to the subsets {}, {0}, {1}, {0,1}, {2}, {0,2}, {1,2}, {0,1,2}.  And this is how the index set for the rows and columns is ordered."""
︡0c09b550-8730-4c48-b78a-92122eb21eff︡{"stdout": "'Unfortunately the ordering of the index set for the rows and columns differs from the paper (and this makes it difficult to see all of the symmetry.  Rows and columns are indexed by subsets of {0,1,2}.  The ordering is given by converting numbers into binary expansions and then viewing binary expansions as subsets.  So, 0,1,2,3,4,5,6,7 have binary expansions 000, 001, 010, 011, 100, 101, 110, 111 and these correspond to the subsets {}, {0}, {1}, {0,1}, {2}, {0,2}, {1,2}, {0,1,2}.  And this is how the index set for the rows and columns is ordered.'"}︡
︠c5e83adb-8606-4dab-8374-d24b7b980049︠
"""Here is latex code for this matrix"""
︡e66ad0d8-ce1b-4d03-9008-641a892bacb2︡{"stdout": "'Here is latex code for this matrix'"}︡
︠584db7e8-5386-4c6d-8911-9fe4acb6f6c5︠
latex(X)
︡45d475da-02ae-4ad9-b0e1-4daab0dec91d︡{"stdout": "\\texttt{[[ 0.25       -0.08333333 -0.08333333  0.         -0.08333333  0.          0.\n   0.        ]\n [-0.08333333  0.10416667  0.03125    -0.04166667  0.03125    -0.04166667\n   0.          0.        ]\n [-0.08333333  0.03125     0.10416667 -0.04166667  0.03125     0.\n  -0.04166667  0.        ]\n [ 0.         -0.04166667 -0.04166667  0.10416667  0.          0.03125\n   0.03125    -0.08333333]\n [-0.08333333  0.03125     0.03125     0.          0.10416667 -0.04166667\n  -0.04166667  0.        ]\n [ 0.         -0.04166667  0.          0.03125    -0.04166667  0.10416667\n   0.03125    -0.08333333]\n [ 0.          0.         -0.04166667  0.03125    -0.04166667  0.03125\n   0.10416667 -0.08333333]\n [ 0.          0.          0.         -0.08333333  0.         -0.08333333\n  -0.08333333  0.25      ]]}"}︡
︠50e8b411-2293-4e60-885a-73f2c391f98c︠
"""Here I compute X's eigenvalues"""
︡93d4c377-a58c-47a1-be56-eec4de873ea3︡{"stdout": "\"Here I compute X's eigenvalues\""}︡
︠e8948b54-0c8f-43fd-9ef5-a6ba5d5e175e︠
X.eigenvalues()
︡f868bc3f-2b4b-4a2a-97f1-e52d96d899e7︡{"stderr": "Traceback (most recent call last):\n  File \"<stdin>\", line 1, in <module>\n  File \"_sage_input_163.py\", line 10, in <module>\n    exec compile(u'open(\"___code___.py\",\"w\").write(\"# -*- coding: utf-8 -*-\\\\n\" + _support_.preparse_worksheet_cell(base64.b64decode(\"WC5laWdlbnZhbHVlcygp\"),globals())+\"\\\\n\"); execfile(os.path.abspath(\"___code___.py\"))' + '\\n', '', 'single')\n  File \"\", line 1, in <module>\n    \n  File \"/tmp/tmp1o5YTh/___code___.py\", line 2, in <module>\n    exec compile(u'X.eigenvalues()' + '\\n', '', 'single')\n  File \"\", line 1, in <module>\n    \nAttributeError: 'matrix' object has no attribute 'eigenvalues'"}︡
︠0dd3eb07-91f0-4ebc-b808-5c9068e03383︠
"""Since the eigenvalues are all non-negative I can conclude that the symmetrization of p, which is 1-(z_1+z_2+z_3+z_4)/4 is an Agler class denominator."""
︡c8feef0b-f06a-4edd-b15f-1e67416b81c3︡{"stdout": "'Since the eigenvalues are all non-negative I can conclude that the symmetrization of p, which is 1-(z_1+z_2+z_3+z_4)/4 is an Agler class denominator.'"}︡
︠2feff380-2cfd-4161-a851-0bed5b47ff31︠
"""Let's try this with the polynomial q(z) = 3-2z, viewed as having degree at most 5."""
︡a68455e1-1d76-4a3b-90c7-07d12ec15141︡{"stdout": "\"Let's try this with the polynomial q(z) = 3-2z, viewed as having degree at most 5.\""}︡
︠25da7a6d-8460-4b5d-bc90-f920af039b37︠
q = [3,-2,0,0,0,0]
︡dd2e8112-434b-4401-ad57-c243c37bfd7e︡︡
︠733c26e9-9518-4344-9552-1b7991bd6d84︠
Y = matrix(Bmatrix(q))
︡5a50fc35-c29e-4459-97a7-81b59a23c75e︡︡
︠03cf8385-d5bf-4b30-aa98-5df25866272e︠
show(Y)
︡40e70085-6bfd-40e8-85b5-48798f0d11ff︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\hbox{[[ 1.8        -0.3        -0.3         0.         -0.3         0.          0.\n   0.         -0.3         0.          0.          0.          0.          0.\n   0.          0.        ]\n [-0.3         0.49        0.05333333 -0.1         0.05333333 -0.1         0.\n   0.          0.05333333 -0.1         0.          0.          0.          0.\n   0.          0.        ]\n [-0.3         0.05333333  0.49       -0.1         0.05333333  0.         -0.1\n   0.          0.05333333  0.         -0.1         0.          0.          0.\n   0.          0.        ]\n [ 0.         -0.1        -0.1         0.32666667  0.          0.02666667\n   0.02666667 -0.1         0.          0.02666667  0.02666667 -0.1         0.\n   0.          0.          0.        ]\n [-0.3         0.05333333  0.05333333  0.          0.49       -0.1        -0.1\n   0.          0.05333333  0.          0.          0.         -0.1         0.\n   0.          0.        ]\n [ 0.         -0.1         0.          0.02666667 -0.1         0.32666667\n   0.02666667 -0.1         0.          0.02666667  0.          0.\n   0.02666667 -0.1         0.          0.        ]\n [ 0.          0.         -0.1         0.02666667 -0.1         0.02666667\n   0.32666667 -0.1         0.          0.          0.02666667  0.\n   0.02666667  0.         -0.1         0.        ]\n [ 0.          0.          0.         -0.1         0.         -0.1        -0.1\n   0.49        0.          0.          0.          0.05333333  0.\n   0.05333333  0.05333333 -0.3       ]\n [-0.3         0.05333333  0.05333333  0.          0.05333333  0.          0.\n   0.          0.49       -0.1        -0.1         0.         -0.1         0.\n   0.          0.        ]\n [ 0.         -0.1         0.          0.02666667  0.          0.02666667\n   0.          0.         -0.1         0.32666667  0.02666667 -0.1\n   0.02666667 -0.1         0.          0.        ]\n [ 0.          0.         -0.1         0.02666667  0.          0.\n   0.02666667  0.         -0.1         0.02666667  0.32666667 -0.1\n   0.02666667  0.         -0.1         0.        ]\n [ 0.          0.          0.         -0.1         0.          0.          0.\n   0.05333333  0.         -0.1        -0.1         0.49        0.\n   0.05333333  0.05333333 -0.3       ]\n [ 0.          0.          0.          0.         -0.1         0.02666667\n   0.02666667  0.         -0.1         0.02666667  0.02666667  0.\n   0.32666667 -0.1        -0.1         0.        ]\n [ 0.          0.          0.          0.          0.         -0.1         0.\n   0.05333333  0.         -0.1         0.          0.05333333 -0.1         0.49\n   0.05333333 -0.3       ]\n [ 0.          0.          0.          0.          0.          0.         -0.1\n   0.05333333  0.          0.         -0.1         0.05333333 -0.1\n   0.05333333  0.49       -0.3       ]\n [ 0.          0.          0.          0.          0.          0.          0.\n  -0.3         0.          0.          0.         -0.3         0.         -0.3\n  -0.3         1.8       ]]}</div>"}︡
︠223eb777-a6c7-46c0-a94f-66234f026dd5︠
Y.eigenvalues()
︡370a755c-d048-4988-92b2-193a6c38d6de︡{"stderr": "Traceback (most recent call last):\n  File \"<stdin>\", line 1, in <module>\n  File \"_sage_input_169.py\", line 10, in <module>\n    exec compile(u'open(\"___code___.py\",\"w\").write(\"# -*- coding: utf-8 -*-\\\\n\" + _support_.preparse_worksheet_cell(base64.b64decode(\"WS5laWdlbnZhbHVlcygp\"),globals())+\"\\\\n\"); execfile(os.path.abspath(\"___code___.py\"))' + '\\n', '', 'single')\n  File \"\", line 1, in <module>\n    \n  File \"/tmp/tmphdBkYj/___code___.py\", line 2, in <module>\n    exec compile(u'Y.eigenvalues()' + '\\n', '', 'single')\n  File \"\", line 1, in <module>\n    \nAttributeError: 'matrix' object has no attribute 'eigenvalues'"}︡
︠9ef92905-80c9-4955-b918-efc85fd0d2de︠
'''In this case Y is positive definite which would provide support to the conjecture that strict stability should make B strictly positive.'''
︡015407bc-0e7b-486a-9aee-75e660d9c820︡{"stdout": "'In this case Y is positive definite which would provide support to the conjecture that strict stability should make B strictly positive.'"}︡
︠38319aec-fa0b-4edd-8baa-eb6dab99b569︠
#findbit(21)
︡e8a8b92f-d25f-4d57-837b-eee601bc086a︡︡
︠83684a5b-9200-4e34-a2d7-8c4983c914f1︠
#s= [2,-3,4,0,0,0]
︡df35780c-db14-4e50-80dc-413b938d3546︡︡
︠e87ac802-a3ee-48c3-8880-6680e476a660︠
#A= matrix(Bmatrix(s))
︡d69ff4ff-6a12-47a8-a723-cddc404de6a6︡︡
︠74c5d4ca-1f56-4f3c-bad5-f2b4361e697c︠
#A
︡81bba9e2-d7e6-4a1c-92d2-0bf8075dfcf2︡︡
︠24d8c324-98c4-45c1-a8fc-a395595660cd︠
#A.eigenvalues()
︡5646545e-a1f6-43f2-bd0a-9ac7d70ade3c︡︡
︠7c2f95b3-7636-4f3a-9b68-f99b169faade︠
def head(items):
    return items[0]
def tail(items):
    return items[1:]
   
def areEigenvaluesPositive(list):
    
    if (list == []):
        return True
    elif (head(list) < 0):
        return False
    else:
        return areEigenvaluesPositive(tail(list))
︡726b1f55-67c8-4d6e-aa09-d8efc133f91e︡︡
︠3e4a1865-044d-465c-9006-67686b1d4be9︠
def isAglerDen():
    for i in range(0,2,1):
        w = [1,-i,0,0,0,0,0,0,0,0,0,0,0]
        C = matrix(Bmatrix(w))
        if areEigenvaluesPositive(C.eigenvalues()) == False:
            print(w,"is not an Agler class denominator")
︡7e06956b-3481-420b-bb20-f1e273e45924︡︡
︠d3815623-b2c3-43f2-8d37-0286705dbb4c︠
#show(isAglerDen())
︡dff02329-992c-4020-ae36-46026381c670︡︡
︠bfecbfb5-d994-4af4-bb7f-97d520091353︠
def findCoeffs():
    import random
    import cmath
    for i in range(0,10,1):
        A = random.uniform(-pi,pi)
        #print("A is",A)
        B = random.uniform(-pi,pi)
        #print("B is",B)
        C = random.uniform(-pi,pi)
        #print("C is",C)
        D = random.uniform(-pi,pi)
        #print("D is",D)
        E = random.uniform(-pi,pi)
        #print("E is",E)
        
        r = random.uniform(-1,1)
        s = random.uniform(-1,1)
        t = random.uniform(-1,1)
        u = random.uniform(-1,1)
        v = random.uniform(-1,1)
        
        a = r*(cos(A) + sin(A)*1j)
        b = s*(cos(B) + sin(B)*1j)
        c = t*(cos(C) + sin(C)*1j)
        d = u*(cos(D) + sin(D)*1j)
        e = v*(cos(E) + sin(E)*1j)
        
        p0 = 1
        p1 = -a-b-c-d-e
        p2 =  a*b + a*c + a*d + a*e + b*c + b*d + b*e + c*d + c*e + d*e
        p3 = -a*b*c - a*b*d - a*b*e - a*c*d - a*c*e - a*d*e - b*c*d - b*c*d - b*c*e - b*d*e - c*d*e
        p4 = a*b*c*d + a*b*c*e + a*b*d*e + a*c*d*e + b*c*d*e
        p5 = -a*b*c*d*e
        print([p0,p1,p2,p3,p4,p5])
︡68de066d-5589-477d-9538-dac672c1b06c︡︡
︠f02fac0e-97d8-4bb5-85d8-e9770dca98d4︠
#show(areEigenvaluesPositive(A.eigenvalues()))
︡94f21742-fea1-4715-b02d-2bf6c0421a81︡︡
︠ced89f3d-9ef8-4fbf-a925-3ca00d5176ad︠
from numpy import *
def findChol(x):
    try:
        factor = linalg.cholesky(x).T
    except:
        factor = None
    return factor
︡54757927-df66-4210-b099-c0ba46b7fe34︡︡
︠a66a0475-bb92-4675-82ac-6ac4971aac87︠
from numpy import *
def isAglerDen2(n):
    L = matrix(Bmatrix(n))
    #E = linalg.eigvals(L)
    D = findChol(L)
    
   
    if (D == None):
        return None
    else:
        return D
︡7ad81da4-5925-41c5-9be9-71d8f252b5d5︡︡
︠d32b3d1f-01f4-4bfd-ad26-87d377ac02af︠
#h = Matrix([[1,0],[0,0]])
︡4e5dd556-23a7-401c-9d34-855d36518443︡︡
︠c5e38aa3-1700-4cd1-b7e1-100aeae94760︠
#show(h.eigenvalues())
︡8858c911-1db3-4a60-8f67-270511e76c49︡︡
︠ff1207f9-0695-4a02-8f0d-9095bf63973f︠
#show(findChol(h))
︡88e41858-d5a5-42e0-918d-d0323897e8ca︡︡
︠671ae191-d5b1-42fd-8ff1-3f2e0c2c0510︠
def findCoeffs2():
    import random
    import cmath
    for i in range(0,100,1):
        A = random.uniform(-pi,pi)
        #print("A is",A)
        B = random.uniform(-pi,pi)
        #print("B is",B)
        C = random.uniform(-pi,pi)
        #print("C is",C)
        D = random.uniform(-pi,pi)
        #print("D is",D)
        E = random.uniform(-pi,pi)
        #print("E is",E)
        
        r = random.uniform(-1,1)
        s = random.uniform(-1,1)
        t = random.uniform(-1,1)
        u = random.uniform(-1,1)
        v = random.uniform(-1,1)
        
        a = r*(cos(A) + sin(A)*1j)
        b = s*(cos(B) + sin(B)*1j)
        c = t*(cos(C) + sin(C)*1j)
        d = u*(cos(D) + sin(D)*1j)
        e = v*(cos(E) + sin(E)*1j)
        
        p0 = 1
        p1 = -a-b-c-d-e
        p2 =  a*b + a*c + a*d + a*e + b*c + b*d + b*e + c*d + c*e + d*e
        p3 = -a*b*c - a*b*d - a*b*e - a*c*d - a*c*e - a*d*e - b*c*d - b*c*d - b*c*e - b*d*e - c*d*e
        p4 = a*b*c*d + a*b*c*e + a*b*d*e + a*c*d*e + b*c*d*e
        p5 = -a*b*c*d*e
        
        p = [p0,p1,p2,p3,p4,p5]
        print(p)
        
        CholFactor = isAglerDen2(p)
        
        if (CholFactor == None):
            print("not an Agler Denominator")
            
            #SPD = areEigenvaluesPositive(Eigs)
            #if (SPD == False):
                #print("not an Agler Denominator")
            #else:
                #print("is an Agler Denominator")
        else:
            print("is an Agler Denominator")
︡dc214eb3-da54-46f0-868a-73d91e7c304e︡︡
︠84613897-be6e-4729-946c-ba174417ad69︠
show(findCoeffs2())
︡ab295dd4-4ef3-4aa8-bf43-8b62497281ee︡{"stdout": "WARNING: Output truncated!"}︡{"html": "<a target='_new' href='/home/rtwalden/0/cells/82/full_output.txt' class='file_link'>full_output.txt</a>"}︡{"stdout": "[1, (-1.2159940850892212+0.18286074218244608j), (0.90415201827208003+0.38820703580078653j), (-0.57281378313827169-0.20847092812354412j), (0.055350356762214309+0.017938653287055371j), (-0.002891979754775475+0.00084209116192375207j)]\nnot an Agler Denominator\n[1, (0.3085435468447506+1.7453216786708385j), (-1.2336075895297467+0.17398472210581115j), (0.18578257062059222-0.83697829201884211j), (0.33552434738439496+0.17766564487474407j), (-0.01319775064624255+0.057446345277074623j)]\nnot an Agler Denominator\n[1, (-0.33081150959434635-0.12387826323360811j), (-0.53186838132732994-0.18644311814110417j), (0.27804692842048717+0.36627788283400714j), (-0.057963257482850923-0.051975461534528006j), (0.0056415173601776555+0.002473268952047906j)]\nis an Agler Denominator\n[1, (-0.83549122223866146+0.18973315728230133j), (0.18732349843968921-0.5631321693340976j), (-0.014806864144151013+0.10689113331099327j), (-0.077848584598077364+0.040282448322226293j), (-0.0012125560303934747+0.013137506741110526j)]\nnot an Agler Denominator\n[1, (-0.15186006973767754-0.34732689586679077j), (-0.47668494803185651+0.31283001578330716j), (0.29289333731423395-0.099582472975836403j), (-0.034874662499699678-0.061844491732730267j), (-0.0057270205418347509+0.012633231356860737j)]\nnot an Agler Denominator\n[1, (0.62319304444823909-0.33052788176123965j), (0.17239103831251035-0.14561359124280304j), (0.093900786278241888+0.25866626975891238j), (0.13184469481170907+0.01315488391805863j), (0.0068619529109816713-0.020187110384229334j)]\nnot an Agler Denominator\n[1, (0.65828285002297648+0.29263090590209301j), (0.32553253752180689-0.56539327310993492j), (0.14807596705677376-0.22596481297955734j), (-0.13081395094053286-0.14807443411340335j), (-0.0040469193395062941-0.0012981084161247183j)]\nnot an Agler Denominator\n[1, (0.73062865757686157+0.92703847640288661j), (-0.031571622514721301+0.80456909053659986j), (-0.50133254211363598+0.31879376583886465j), (0.054704213289621273-0.15617358746311732j), (0.02017554965768863+0.005667402138692091j)]\nnot an Agler Denominator\n[1, (0.45541682071327283-0.11464758012404791j), (0.26654793757257972+0.27475841058320027j), (0.1256087890842498+0.0014736185896842388j), (0.0073065449448997148+0.0036468940930634631j), (0.00035797239579554138+0.00033921041515084344j)]\nis an Agler Denominator\n[1, (-1.4686707054316919-0.13709899315577068j), (1.4678461483581486+0.8681963850119685j), (-1.0730280185504044-0.66647309927730047j), (0.32612116097096022+0.55254092811197364j), (-0.036618102240068062-0.12798137205686633j)]\nnot an Agler Denominator\n[1, (1.1937693955890687+0.70362623044827266j), (-0.16450637802221776+0.91915692198328147j), (-0.83535235387352647+0.38011337515501376j), (-0.12652933068117789-0.11357589736236257j), (0.028135535791375565-0.031933865564001171j)]\nnot an Agler Denominator\n[1, (0.32250188320132145+0.25971526909555381j), (0.20924914265800332-0.070908361542175766j), (-0.11260553412981866+0.080500422655765319j), (0.015697715558335681+0.0017721145602553703j), (-0.00068130118481180089-0.0011179582689776471j)]\nis an Agler Denominator\n[1, (0.22860790622451899-0.24577441806444975j), (-0.0991199551221182-0.31250794423217654j), (-0.042664168733658261-0.047520596441583511j), (-0.0087715676754247292+0.0020824882655705772j), (0.00021552526512458583+0.00011990317533817999j)]\nis an Agler Denominator\n[1, (-0.041502793087050849+1.1329355039352929j), (-0.59880084738847394-0.034784768425319385j), (-0.022533274174558471-0.14117389281807283j), (0.0041201287457279237-0.0051615059183782756j), (9.0428948088231874e-05-1.5405887737303419e-05j)]\nnot an Agler Denominator\n[1, (-1.7917375088084604+1.0231029853622471j), (0.81636503495027846-1.1648212381091081j), (-0.18381998878911127+0.28090956013587065j), (0.02479761767812368-0.024131542320679353j), (-0.00070343793137239501+0.00022347687372840927j)]\nnot an Agler Denominator\n[1, (0.59713706276748901+1.7249461750335735j), (-0.91214667760294887+0.84787956534478692j), (-0.25725253966786404-0.13135344507122354j), (0.029223230676625543-0.023451639317783202j), (0.0020541795911339982+0.011563902249780825j)]\nnot an Agler Denominator\n[1, (-1.3077361291797664-0.45699680809496457j), (0.38635392849633204+0.28537861641267259j), (-0.06001598856363495+0.003612349662417684j), (-0.00475248792547062-0.015206708564406889j), (0.00027984450069934604+0.00055705917940246667j)]\nnot an Agler Denominator\n[1, (-0.63544801628007808-0.58067550364595166j), (0.074830710121127408+0.58982345036814376j), (-0.074818303950451456+0.056515311297875737j), (0.021744519082553353+0.0013375060494480329j), (-0.0025324501836661486+0.001036897284242333j)]\nnot an Agler Denominator\n[1, (-0.28272112335570176+1.1880498401570712j), (-0.27345555105505692+0.20165060869013071j), (-0.18692671165779243-0.11740060522476835j), (0.073259862828111921-0.10392106743533067j), (0.010931758409578192+0.00033229605218431258j)]\nnot an Agler Denominator\n[1, (0.94645886048726147-0.6257358314701873j), (-0.15372862442898039-0.72641958697520348j), (-0.27883511644624914-0.10694083385126912j), (-0.048503810721867935+0.038787927318655144j), (0.0034390077351782958+0.0082735248286375657j)]\nnot an Agler Denominator\n[1, (-0.83259927277625789-1.0472095447190923j), (-0.13841728623832855+1.0100006826679966j), (0.25752054841789351+0.06382890294003879j), (0.060908596634021442-0.0057821127809151978j), (0.012831288767568451-0.0015223174666513495j)]\nnot an Agler Denominator\n[1, (0.51086745552704804-0.88700051947974967j), (-0.22671211262025912-0.32395810479193315j), (-0.061879104556627526+0.025486626168746619j), (0.0037599181192145528+0.0030748131943301848j), (1.2335826661528098e-05-0.0001105413040996922j)]\nnot an Agler Denominator\n[1, (-0.18269310308881487-1.5381439404845754j), (-1.2222767581519611+0.18964347064197282j), (-0.17519078092714277+0.53795022596205078j), (0.090637580946971164+0.042172077347702223j), (-0.0030724454371874811-0.0018973844167167553j)]\nnot an Agler Denominator\n[1, (-0.15780777357633058-0.41857314490761194j), (-0.47016511820394891+0.64089502055298497j), (0.65745927921534719+0.14767830937156357j), (-0.24186319715205806-0.084551121108314642j), (-0.0015155849543170979+0.32276870579992167j)]\nnot an Agler Denominator\n[1, (0.46163872669698991+1.4563653612770753j), (-0.54388448492495955+0.49471586597646172j), (-0.08440355038453376+0.028357051849786975j), (-0.024471502426298374+0.027447676097499984j), (0.00081520214242803595+0.00068595213624137569j)]\nnot an Agler Denominator\n[1, (0.97100049719868475+1.1857569822755392j), (0.13482695991613955+0.76317364640052809j), (0.22490603017069405+0.5781070660730222j), (-0.12152336511851691+0.10437585365688332j), (-0.015346760689258103-0.0051841171231202347j)]\nnot an Agler Denominator\n[1, (-0.38146201349280862-0.10846961336548924j), (0.41625410133188445+0.10508602858839103j), (0.19254258108377911-0.059684555212506582j), (0.0078630369788042897-0.0040412772552245084j), (-0.00047628450299842448+0.00030322157966155167j)]\nis an Agler Denominator\n[1, (-1.2619837213530092-0.42859822985425589j), (1.2152295358613352+0.1661882271250433j), (-0.4786497663906078-0.29007582012879674j), (0.017577870974127382+0.030757086307379496j), (-0.00035521376475035782+0.0014775613299294621j)]\nnot an Agler Denominator\n[1, (-0.71717810139085436+0.49155730291587807j), (0.45202562569004423-0.019513917917856838j), (0.054596456145739464+0.10361307699120069j), (0.0020944030199876208+0.10125809698252813j), (-0.012249927511644193-0.0090474557505622662j)]\nnot an Agler Denominator\n[1, (1.1246971335592286+0.045595695400519776j), (0.67191041392037554-0.35068357472495004j), (0.23115564369237038-0.25310379162913071j), (0.047211014929395105-0.063499663479360827j), (-0.0028388192319670214-0.020679014623156841j)]\n\n...\n\nnot an Agler Denominator\n[1, (-0.36920721484598418-0.61459726193345465j), (0.081084994240908023+0.50947424195854152j), (0.13904555500773388-0.20624921463726653j), (-0.078753207224596999+0.021553897228053932j), (-0.00066932083316767043+0.0075754909551884568j)]\nnot an Agler Denominator\n[1, (0.042310722999333229+0.25884525222619781j), (0.13534858998314933-0.0099149859555571762j), (0.053044766551901247-0.11517212232180318j), (-0.0098137473056484521-0.014081688906133878j), (0.01620733480320417-0.0055650048828752973j)]\nis an Agler Denominator\n[1, (-0.065688442771178412-1.6322562258296478j), (-1.0113840483920526-0.061076241082995197j), (-0.19979977694735557+0.29411872287992913j), (0.031663794075153157+0.040599542710952792j), (0.0093941595006820262+0.0057986531466660586j)]\nnot an Agler Denominator\n[1, (-1.5944187468639512-0.38856761686435504j), (0.69262851519541713-0.52506832370523371j), (-0.55600954714145945+1.1279527580396151j), (0.42490797609347875-0.22630118210284061j), (-0.0079783222914109539-0.056287351684770656j)]\nnot an Agler Denominator\n[1, (0.69104749059150494-1.048043424799262j), (-0.18409264377958406-0.78713570420687085j), (-0.23676183378856697-0.1674906647907225j), (-0.035070862682941531+0.020138874361324832j), (0.0042328315892200367+0.0020100525025165948j)]\nnot an Agler Denominator\n[1, (-0.85757579086828228+1.2144577657263822j), (-0.92057868092908557-1.089082690119054j), (1.3275351737492269-0.013504735034395386j), (-0.080590065473969213+0.16357690425068078j), (0.0055429808828366591+0.028304175773271857j)]\nnot an Agler Denominator\n[1, (1.3282714474365624-0.68513001787480676j), (0.38102027714958409-0.69492076256190594j), (-0.02253045109397531-0.18972117112713149j), (-0.012365930014690418-0.013053091147250543j), (-0.00038528112493044491-0.00015751228261345399j)]\nnot an Agler Denominator\n[1, (-1.1459972022130831-0.052889388843146867j), (0.81949694588433797+0.25902549364241639j), (-0.99319920395349393-0.66391549716763687j), (0.069930143734814237+0.24436837769727318j), (0.0075824189539404376-0.00019923958187739082j)]\nnot an Agler Denominator\n[1, (1.1962996146129619-0.015253269039951667j), (0.77992180076573492-0.38992028946848628j), (0.43933185164791805-0.43414114982680391j), (0.03071233766803079-0.1914563098849954j), (-0.007803282191283711-0.045112785577210775j)]\nnot an Agler Denominator\n[1, (0.33212927871992182-0.76652901925136885j), (-0.76687689813838877-0.02501702469543006j), (-0.74400367464691242+0.47594716331833392j), (-0.07148769091439286+0.01085085734055668j), (-0.0013833669583039525+9.0760219866019778e-05j)]\nnot an Agler Denominator\n[1, (-0.3182204291003109+0.90158486638460422j), (-0.24573142027016556-0.49052294178121791j), (0.0092862560765576904-0.11743186282004285j), (0.0054680550842300816-0.027441062582606313j), (-0.00019018407531786548-0.0012874915880170766j)]\nnot an Agler Denominator\n[1, (-0.62714168901252709-0.39332313228896509j), (0.32514335280491302+0.37691011380930162j), (-0.37130862833530986-0.081930503431302384j), (0.011143050831318072-0.005633972879122838j), (-0.0011983940066318363-0.0064822814694749297j)]\nnot an Agler Denominator\n[1, (0.40241564990252859-0.9340211746639635j), (0.58915564707019608-0.51303294549836098j), (-0.18023517298930117-0.58491867269690989j), (-0.12935961016211639+0.058059002685818831j), (0.0090487561440505578-0.0027470999515601139j)]\nnot an Agler Denominator\n[1, (1.0680640322808603+0.17602983838648728j), (0.54561376266110739+0.76000141465128335j), (0.39606185681575651+0.74199701793276529j), (-0.041713843762761396+0.10872897182424095j), (-0.0019214481184036607+0.0015847041151023518j)]\nnot an Agler Denominator\n[1, (-0.29971712098954106+1.0660413133314524j), (-0.30090319847674107-0.22640791392679871j), (0.031619171419713321-0.046683289319798205j), (0.010125671428068998+0.0096293888780969276j), (-0.00074456431208503313+0.0012892580948014173j)]\nnot an Agler Denominator\n[1, (0.88565959317978704+0.67272773475912451j), (-0.64560528235749215+1.4980315610819179j), (-1.0840394163100404+1.0681561566442086j), (-0.42411411452304021-0.43760715898317082j), (-0.13922332455538602-0.20672800037057787j)]\nnot an Agler Denominator\n[1, (0.2142279543922061+0.3800432508605065j), (-0.051478735821590245+0.063079742192959948j), (-0.0086803026569600289-0.0020246255876992577j), (-0.0001538169884389948-0.00057338719541971455j), (2.6145245626334863e-06-1.2911253331180014e-05j)]\nis an Agler Denominator\n[1, (-0.64404663925335282-0.92636412723323636j), (-0.26870564304356603+0.45340553248086057j), (0.11933977064913691+0.043716811657745672j), (0.0090878995773456435-0.0055091631456004667j), (-5.8574975820004565e-05-0.00032826644431444349j)]\nnot an Agler Denominator\n[1, (1.0710333735850348-0.20434928055513291j), (0.2227106723523701-0.3829915421894825j), (0.021910218191482769-0.089396226371113122j), (-0.0038895465904495489-0.0099331514915973508j), (-0.00055242462820252866-0.00013064497866686485j)]\nnot an Agler Denominator\n[1, (-0.53344519425458503-0.060112224163490602j), (0.32668978772718527+0.14126867647776059j), (-0.10147008904588917-0.062127806354856069j), (0.012873322993873188+0.0088508433360684671j), (-0.00035343203681101662-0.00055366751047338045j)]\nis an Agler Denominator\n[1, (0.089884445278091585-0.57747935895654545j), (-0.30101954922460328-0.035804010270400477j), (0.10982195551746979-0.069744041499634465j), (-0.025607171629917099-0.06591926993085484j), (-0.0037863874511541475+0.0008753630853923194j)]\nnot an Agler Denominator\n[1, (0.078755152803549749+1.0736558094851942j), (-0.58640007959707829+0.24256539126078067j), (-0.32342855267685916-0.27980621088223201j), (-0.0037365469517738198-0.013349982144890145j), (-0.0011389160591723708-0.0036846274473337111j)]\nnot an Agler Denominator\n[1, (1.4273349035361282+0.018446586315254421j), (0.55410139652803714+0.20934444629156734j), (-0.017679943126310826+0.23994646381912874j), (-0.0050398490325340023+0.048629059018074045j), (0.0047862758490256688+0.0017303657862558033j)]\nis an Agler Denominator\n[1, (0.24979355340417886+2.2250771841304706j), (-1.6831457387902951+1.235480764021524j), (-1.0122183360021082-1.1478478859991881j), (-0.014214630061305217-0.41318920050254138j), (-0.098417106377368807-0.052585165935205208j)]\nnot an Agler Denominator\n[1, (-1.2466319911262462-1.9988325139196925j), (-1.2463077771954811+2.0435944209193511j), (1.2030444296078362+0.30204991497743994j), (-0.0039825436190204025-0.32769845825683919j), (-0.04195892992791065-0.013981189652980218j)]\nnot an Agler Denominator\n[1, (-1.3321204313053947-0.18239323956135398j), (0.99282649330745931-0.37050707800731342j), (-0.38286694637586166+0.41046950753554162j), (-0.064172226209425212-0.19647729249520474j), (0.022648539896352751-0.0022592844133256327j)]\nnot an Agler Denominator\n[1, (1.2719413897814649+0.93198357740582716j), (-0.015559721485125716+1.3657077096997747j), (-0.4417316477410238+0.61329680077917781j), (-0.17502850772418541-0.014487209466920288j), (-0.016917317073954899-0.0083478879313986856j)]\nnot an Agler Denominator\n[1, (-0.66537768473470271-0.93903026107650089j), (-0.11365318067264049+1.2280189762474114j), (0.74388421823182038-0.40629235002488717j), (-0.20849192626928548+0.091245550999745073j), (-0.0015944812926672912-0.0012173570145676423j)]\nnot an Agler Denominator\n[1, (0.90713033760926765+0.91085446257760672j), (0.030798945659915034+0.51520130341820969j), (-0.14205923632052969+0.079436901517177513j), (-0.059150850709227244+0.026990300174906529j), (-0.0073235700279476006+0.0071694929769499215j)]\nnot an Agler Denominator"}︡{"html": "<div class=\"math\">\\newcommand{\\Bold}[1]{\\mathbf{#1}}\\hbox{None}</div>"}︡
